# IOT at you service with LoraWan and Ruby
### Manage your devices with Loriot cloud system

[![Version     ](https://badge.fury.io/rb/loriot-rb.svg)                        ](https://rubygems.org/gems/loriot-rb)
[![Travis CI   ](http://img.shields.io/travis/marcomd/loriot-rb/master.svg)     ](https://travis-ci.org/marcomd/loriot-rb)
[![Quality     ](http://img.shields.io/codeclimate/github/marcomd/loriot-rb.svg)](https://codeclimate.com/github/marcomd/loriot-rb)

### What is Lora?

LoRaWAN is a Low Power Wide Area Network with features that support low-cost, mobile, and secure bi-directional communication for Internet of Things (IoT), machine-to-machine (M2M), and smart city, and industrial applications. LoRaWAN is optimized for low power consumption and is designed to support large networks with millions and millions of devices. Innovative features of LoRaWAN include support for redundant operation, geolocation, low-cost, and low-power - devices can even run on energy harvesting technologies enabling the mobility and ease of use of Internet of Things.


![](/assets/LoraWan_Description.jpg)


## Install

    gem install loriot-rb

To use it in a bundle, add to gem file `gem 'loriot-rb'` and run `bundle install`

## Connection to loriot server

Establish a secure connection to your `Loriot Application` on the cloud.

This version only support the TLS protocol.

From irb require the library:

```ruby
require 'loriot-rb'
```

then create an instance

```ruby
lora = LoriotClient.new
```

if you are in debug mode you should also receive a json:

```json
{ "hello":"LORIOT.io TLS Server", "version":"1.0.4" }
```

### Send data to a device


```ruby
lora.send_cmd(EUI: 'Insert here your EUI code', confirmed: true, data: "0101")
```

Request example:

```json
{ "cmd":"tx", "EUI":"BE7A0000000010B7", "port":40, "confirmed":false, "data":"0101" }
```

Response example:

```json
{ "cmd":"txd", "EUI":"BE7A0000000010B7", "seqdn":114, "seqq":113, "ts":1489133179385 }
```

`"cmd":"txd"` show the data sent to the gateway

The response could also be:

```json
{ "cmd":"tx", "EUI":"BE7A0000000010CF", "seqdn": 4, "data": "0301", "success": "Data enqueued" }
```

### Receive Data

To listen your devices:

```ruby
lora.listen
```

### Close the connection

```ruby
lora.quit
```

## Compatibility

Ruby `2.3+`

## Install

    gem install loriot-rb

To use it in a bundle, add to gem file `gem 'loriot-rb'` and run `bundle install`

## To Do

- [x] Connect to a device with tls protocol `v0.1.0`
- [x] Send data to a device `v0.1.0`
- [x] Receive data from a device `v0.2.0`
- [x] Organization in modules to support new protocols  `v0.2.0`
- [x] Add a configuration `v0.3.0`
- [x] Add a rails generator `v0.3.0`
- [ ] Test with many devices

## Contributing

1. Fork it
2. Create your feature branch (`git checkout -b my-feature`)
3. Commit your changes (`git commit -am 'I made extensive use of all my creativity'`)
4. Push to the branch (`git push origin my-feature`)
5. Create new Pull Request

## Testing

Wide coverage with `xx unit tests` and `xxx assertions`

To test locally install the development requirements:

    bundle install

Then execute:

    bundle exec ruby test/unit_test.rb

Performance tests:

    bundle exec ruby test/performance_test.rb


## Found a bug?

Please open an issue.


## License

The GNU Lesser General Public License, version 3.0 (LGPL-3.0)
See LICENSE file
